==> bulletinHD-2.1.zip: xoops_trust_path/modules/bulletin/language/schinese/main.php <==
<?php /* English Translation by Marcelo Yuji Himoro <http://yuji.ws> */

//          index.php          //
define('_MD_PRINTER', 'ӡҳ');
define('_MD_SENDSTORY', 'ת');
define('_MD_READMORE', 'Ķ...');
define('_MD_COMMENTS', '0');
define('_MD_ONECOMMENT', '1');
define('_MD_BYTESMORE', '%sֽ');
define('_MD_NUMCOMMENTS', '%s');

//          submit.php          //
define('_MD_SUBMITNEWS', 'ύ');
define('_MD_TITLE', '');
define('_MD_TOPIC', '');
define('_MD_THESCOOP', '');
define('_MD_NOTIFYPUBLISH', 'ͨʱԵʼ֪ͨ');
define('_MD_POST', '');
define('_MD_GO', '');
define('_MD_THANKS', 'лṩšȴվԱ˷'); //submission of news article
define('_MD_THANKS_AUTOAPPROVE', 'ллͶ塣');
define('_MD_THANKS_BUT_ERROR', 'лͶ塣ǣΪһ<span style="color:red"></span>ûзɴɵĲ㣬¡ҲϵվԱ');
define('_MD_USE_HTML', 'HTML');
define('_MD_USE_SMILEY', 'ñ');
define('_MD_USE_BR', 'Զ');
define('_MD_USE_XCODE', 'XOOPS');
define('_MD_NO_TOPICS', 'Ŀǰûκ');
define("_MD_TOPIC_IMAGE","ͼʾ"); // ver 2.00 added
define("_MD_TOPIC_DISABLE","ʾͼʾ"); // ver 2.00 added
define("_MD_TOPIC_LEFT","ʾͼʾ"); // ver 2.00 added
define("_MD_TOPIC_RIGHT","ʾͼʾұ"); // ver 2.00 added
define("_MD_PUBINHOME","ҳ"); // ver 2.00 added
define("_MD_PUBLISHED",""); // ver 2.00 added
define("_MD_EXPIRED","ѹ"); // ver 2.00 added
define("_MD_SETDATETIME","趨ʱ"); // ver 2.00 added
define("_MD_SETDATETIME_DESC","* ûйѡ򷢲ʱΪǰʱ䡣"); // ver 2.00 added
define("_MD_SETEXPDATETIME","趨ʱ"); // ver 2.00 added
define("_MD_SETEXPDATETIME_DESC","* ûйѡ趨Ч"); // ver 2.00 added
define("_MD_APPROVE","˴¡"); // ver 2.00 added
define("_MD_DATE_FORMAT","%d %m %y %h : %i : %s"); // ver 2.00 added
define("_MD_DBPUDATED","ݿѳɹ£"); // ver 2.00 added
define("_MD_POSTEDBY",""); // ver 2.00 added
define("_MD_RELATION",""); // ver 2.00 added
define("_MD_ADD_RELATION",""); // ver 2.00 added
define("_MD_CHECKED_AS_RELATION","Ϊ¼"); // ver 2.00 added
define("_MD_DISP_BLOCK","ʾ"); // ver 2.00 added
define("_MD_RUSUREDEL","ǷȷҪɾżۣ"); // ver 2.00 added
define("_MD_EMPTYNODELETE", "δɾ"); // ver 2.00 added
//          archive.php          //
define('_MD_NEWSARCHIVES', 'Ŵ浵');
define('_MD_ARTICLES', 'ű');
define('_MD_VIEWS', 'Ķ');
define('_MD_DATE', '');
define('_MD_ACTIONS', 'ѡ');
define('_MD_PRINTERFRIENDLY', 'ӡҳ');
define('_MD_THEREAREINTOTAL', '%sƪš');
define('_MD_INTARTICLE', 'ڡ%sһƪȤ');
define('_MD_INTARTFOUND', 'ڡ%sϷֵһƪ');
define('_MD_TOPICC', '');
define('_MD_URL', 'ӵַ (URL)');
define('_MD_NOSTORY', 'Ǹѡ²ڡ');
define('_MD_YEAR_X', '%s');
define('_MD_NO_ARCIVES', 'Ŀǰûκδ浵');
define('_MD_JANUARY', 'һ');
define('_MD_FEBRUARY', '');
define('_MD_MARCH', '');
define('_MD_APRIL', '');
define('_MD_MAY', '');
define('_MD_JUNE', '');
define('_MD_JULY', '');
define('_MD_AUGUST', '');
define('_MD_SEPTEMBER', '');
define('_MD_OCTOBER', 'ʮ');
define('_MD_NOVEMBER', 'ʮһ');
define('_MD_DECEMBER', 'ʮ');

//          print.php          //

define('_MD_URLFORSTORY', 'ƪµӵַǣ');
define("_MD_THISCOMESFROM","ڡ%sĶš");// %s represents your site name

//          header.php          //
define("_MD_RSS", "RSS");
define("_MD_ARCHIVES","Ŵ浵"); // ver 2.00 added
?>

==> bulletinHD-2.2.zip: xoops_trust_path/modules/bulletin/language/schinese/main.php <==
<?php /* English Translation by Marcelo Yuji Himoro <http://yuji.ws> */

//          index.php          //

// Appended by Xoops Language Checker -GIJOE- in 2009-08-26 16:24:55
define('_MD_INPUTHELPER','Input Helper ON/OFF');
define('_MD_FCKXOOPS_ONOFF','FCK Editor ON/OFF (Note: Each of editors don&#039;t share the text)');
define('_MD_ERROR_REQUIRED','{0} is a required field.');

define('_MD_PRINTER', 'ӡҳ');
define('_MD_SENDSTORY', 'ת');
define('_MD_READMORE', 'Ķ...');
define('_MD_COMMENTS', '0');
define('_MD_ONECOMMENT', '1');
define('_MD_BYTESMORE', '%sֽ');
define('_MD_NUMCOMMENTS', '%s');

//          submit.php          //
define('_MD_SUBMITNEWS', 'ύ');
define('_MD_TITLE', '');
define('_MD_TOPIC', '');
define('_MD_THESCOOP', '');
define('_MD_NOTIFYPUBLISH', 'ͨʱԵʼ֪ͨ');
define('_MD_POST', '');
define('_MD_GO', '');
define('_MD_THANKS', 'лṩšȴվԱ˷'); //submission of news article
define('_MD_THANKS_AUTOAPPROVE', 'ллͶ塣');
define('_MD_THANKS_BUT_ERROR', 'лͶ塣ǣΪһ<span style="color:red"></span>ûзɴɵĲ㣬¡ҲϵվԱ');
define('_MD_USE_HTML', 'HTML');
define('_MD_USE_SMILEY', 'ñ');
define('_MD_USE_BR', 'Զ');
define('_MD_USE_XCODE', 'XOOPS');
define('_MD_NO_TOPICS', 'Ŀǰûκ');
define("_MD_TOPIC_IMAGE","ͼʾ"); // ver 2.00 added
define("_MD_TOPIC_DISABLE","ʾͼʾ"); // ver 2.00 added
define("_MD_TOPIC_LEFT","ʾͼʾ"); // ver 2.00 added
define("_MD_TOPIC_RIGHT","ʾͼʾұ"); // ver 2.00 added
define("_MD_PUBINHOME","ҳ"); // ver 2.00 added
define("_MD_PUBLISHED",""); // ver 2.00 added
define("_MD_EXPIRED","ѹ"); // ver 2.00 added
define("_MD_SETDATETIME","趨ʱ"); // ver 2.00 added
define("_MD_SETDATETIME_DESC","* ûйѡ򷢲ʱΪǰʱ䡣"); // ver 2.00 added
define("_MD_SETEXPDATETIME","趨ʱ"); // ver 2.00 added
define("_MD_SETEXPDATETIME_DESC","* ûйѡ趨Ч"); // ver 2.00 added
define("_MD_APPROVE","˴¡"); // ver 2.00 added
define("_MD_DATE_FORMAT","%d %m %y %h : %i : %s"); // ver 2.00 added
define("_MD_DBPUDATED","ݿѳɹ£"); // ver 2.00 added
define("_MD_POSTEDBY",""); // ver 2.00 added
define("_MD_RELATION",""); // ver 2.00 added
define("_MD_ADD_RELATION",""); // ver 2.00 added
define("_MD_CHECKED_AS_RELATION","Ϊ¼"); // ver 2.00 added
define("_MD_DISP_BLOCK","ʾ"); // ver 2.00 added
define("_MD_RUSUREDEL","ǷȷҪɾżۣ"); // ver 2.00 added
define("_MD_EMPTYNODELETE", "δɾ"); // ver 2.00 added
//          archive.php          //
define('_MD_NEWSARCHIVES', 'Ŵ浵');
define('_MD_ARTICLES', 'ű');
define('_MD_VIEWS', 'Ķ');
define('_MD_DATE', '');
define('_MD_ACTIONS', 'ѡ');
define('_MD_PRINTERFRIENDLY', 'ӡҳ');
define('_MD_THEREAREINTOTAL', '%sƪš');
define('_MD_INTARTICLE', 'ڡ%sһƪȤ');
define('_MD_INTARTFOUND', 'ڡ%sϷֵһƪ');
define('_MD_TOPICC', '');
define('_MD_URL', 'ӵַ (URL)');
define('_MD_NOSTORY', 'Ǹѡ²ڡ');
define('_MD_YEAR_X', '%s');
define('_MD_NO_ARCIVES', 'Ŀǰûκδ浵');
define('_MD_JANUARY', 'һ');
define('_MD_FEBRUARY', '');
define('_MD_MARCH', '');
define('_MD_APRIL', '');
define('_MD_MAY', '');
define('_MD_JUNE', '');
define('_MD_JULY', '');
define('_MD_AUGUST', '');
define('_MD_SEPTEMBER', '');
define('_MD_OCTOBER', 'ʮ');
define('_MD_NOVEMBER', 'ʮһ');
define('_MD_DECEMBER', 'ʮ');

//          print.php          //

define('_MD_URLFORSTORY', 'ƪµӵַǣ');
define("_MD_THISCOMESFROM","ڡ%sĶš");// %s represents your site name

//          header.php          //
define("_MD_RSS", "RSS");
define("_MD_ARCHIVES","Ŵ浵"); // ver 2.00 added
?>
